# This CPAN::Config was automatically generated using /usr/local/cpanel/scripts/cpan_config
# at Fri May 30 01:31:39 2025
#
# If this Config.pm replaced an existing version, then it would be located at:
#     /usr/share/perl5/CPAN/Config.pm.1748568699


# This is CPAN.pm's systemwide configuration file. This file provides
# defaults for users, and the values can be changed in a per-user
# configuration file.

$CPAN::Config = {
  'auto_commit' => q[1],
  'build_cache' => q[10],
  'build_dir' => q[/home/.cpan/build],
  'cache_metadata' => q[1],
  'connect_to_internet_ok' => q[no],
  'cpan_home' => q[/home/.cpan],
  'dontload_hash' => {  },
  'ftp' => q[/bin/false],
  'ftp_proxy' => q[],
  'getcwd' => q[cwd],
  'gzip' => q[/bin/gzip],
  'histfile' => q[/home/.cpan/histfile],
  'histsize' => q[100],
  'http_proxy' => q[],
  'inactivity_timeout' => q[310],
  'index_expire' => q[1],
  'inhibit_startup_message' => q[1],
  'keep_source_where' => q[/home/.cpan/sources],
  'lynx' => q[],
  'make' => q[/usr/bin/make],
  'make_arg' => q[],
  'make_install_arg' => q[UNINST=1],
  'makepl_arg' => q[],
  'mbuild_arg' => q[],
  'mbuild_install_arg' => q[],
  'mbuild_install_build_command' => q[./Build],
  'mbuildpl_arg' => q[],
  'ncftpget' => q[],
  'no_proxy' => q[],
  'pager' => q[/usr/bin/less],
  'prefer_installer' => q[EUMM],
  'prerequisites_policy' => q[follow],
  'scan_cache' => q[atstart],
  'shell' => q[/bin/bash],
  'tar' => q[/bin/gtar],
  'term_is_latin' => q[1],
  'unzip' => q[/usr/bin/unzip],
  'urllist' => [q[http://www.cpan.org//], q[http://103.15.48.49/pub/CPAN/], q[http://31.22.112.31/pub/CPAN/], q[http://185.125.185.32/pub/CPAN/], q[http://208.74.123.62/pub/CPAN/], q[http://103.72.162.35/pub/CPAN/], q[http://209.133.199.70/pub/CPAN/], q[http://185.15.22.168/pub/CPAN/], q[http://110.232.143.226/pub/CPAN/], q[http://184.94.196.93/pub/CPAN/], q[http://103.101.161.235/pub/CPAN/], q[http://201.159.169.169/pub/CPAN/], q[http://184.94.196.94/pub/CPAN/], q[http://185.157.208.252/pub/CPAN/], q[http://184.94.196.92/pub/CPAN/], q[http://184.94.196.97/pub/CPAN/], q[http://102.22.80.80/pub/CPAN/], q[http://103.17.8.8/pub/CPAN/], q[http://185.90.57.221/pub/CPAN/], q[http://208.74.123.61/pub/CPAN/], q[http://45.234.92.141/pub/CPAN/], q[http://103.120.66.133/pub/CPAN/], q[http://63.247.64.58/pub/CPAN/], q[http://203.174.85.202/pub/CPAN/], q[http://45.228.65.220/pub/CPAN/], q[http://103.163.138.20/pub/CPAN/]],
  'use_sqlite' => q[0],
  'wget' => q[/usr/bin/wget],
};
1;
__END__
